Helper functions for the Backpex mix tasks.
Summary
Functions
Updates a file by adding a line if it doesn't already exist.
Checks if a specific string exists within a module's source code.
Checks if an npm package is already installed in the project.
Gets the Phoenix PubSub module from the application configuration.
Checks if a specific string exists within a source's content.
Gets the web folder path for the Phoenix application.
Functions
Updates a file by adding a line if it doesn't already exist.
Checks if a specific string exists within a module's source code.
Checks if an npm package is already installed in the project.
Gets the Phoenix PubSub module from the application configuration.
Checks if a specific string exists within a source's content.
Gets the web folder path for the Phoenix application.